Enum Display
pub enum Display {
Block,
Flex,
Grid,
None,
}Expand description
Sets the layout used for the children of this node
The default values depends on on which feature flags are enabled. The order of precedence is: Flex, Grid, Block, None.
Variants
Block
The children will follow the block layout algorithm
Flex
The children will follow the flexbox layout algorithm
Grid
The children will follow the CSS Grid layout algorithm
None
The node is hidden, and it’s children will also be hidden
Implementations