Enum FlexWrap
pub enum FlexWrap {
NoWrap,
Wrap,
WrapReverse,
}Expand description
Controls whether flex items are forced onto one line or can wrap onto multiple lines.
Defaults to FlexWrap::NoWrap
Variants
NoWrap
Items will not wrap and stay on a single line
Wrap
Items will wrap according to this item’s FlexDirection
WrapReverse
Items will wrap in the opposite direction to this item’s FlexDirection