pub enum ObjectFit {
Fill,
Contain,
Cover,
ScaleDown,
None,
}Expand description
How the content of a replaced element, such as an img, should be resized to fit its container.
Corresponds to the CSS object-fit property.
See https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit.
Variants
Fill
The replaced content is sized to fill the element’s content box. The entire object will completely fill the box. If the object’s aspect ratio does not match the aspect ratio of its box, then the object will be stretched to fit.
Contain
The replaced content is scaled to maintain its aspect ratio while fitting within the element’s content box. The entire object is made to fill the box, while preserving its aspect ratio, so the object will be “letterboxed” if its aspect ratio does not match the aspect ratio of the box.
Cover
The content is sized to maintain its aspect ratio while filling the element’s entire content box. If the object’s aspect ratio does not match the aspect ratio of its box, then the object will be clipped to fit.
ScaleDown
The content is sized as if none or contain were specified, whichever would result in a smaller concrete object size.
None
The replaced content is not resized.