pub enum StyleValue<T> {
Animated(T),
Val(T),
Unset,
Base,
}Expand description
The value for a [Style] property in the public API.
This represents the result of reading a style property, with additional
states like Base that indicate inheritance from parent styles.
Variants
Animated(T)
Value inserted by animation interpolation
Val(T)
Value set directly
Unset
Use the default value for the style, typically from the underlying ComputedStyle.
Base
Use whatever the base style is. For an overriding style like hover, this uses the base
style. For the base style, this is equivalent to Unset.
Implementations