pub struct BoxShadow {
pub blur_radius: PxPct,
pub color: Color,
pub spread: PxPct,
pub left_offset: PxPct,
pub right_offset: PxPct,
pub top_offset: PxPct,
pub bottom_offset: PxPct,
}Expand description
Structure holding data about the shadow.
Fields
blur_radius: PxPctcolor: Colorspread: PxPctleft_offset: PxPctright_offset: PxPcttop_offset: PxPctbottom_offset: PxPctImplementations
Sourceimpl BoxShadow
impl BoxShadow
Sourcepub fn blur_radius(self, radius: impl Into<PxPct>) -> Self
pub fn blur_radius(self, radius: impl Into<PxPct>) -> Self
Specifies shadow blur. The larger this value, the bigger the blur, so the shadow becomes bigger and lighter.
Sourcepub fn spread(self, spread: impl Into<PxPct>) -> Self
pub fn spread(self, spread: impl Into<PxPct>) -> Self
Specifies shadow blur spread. Positive values will cause the shadow to expand and grow bigger, negative values will cause the shadow to shrink.
Sourcepub fn left_offset(self, left_offset: impl Into<PxPct>) -> Self
pub fn left_offset(self, left_offset: impl Into<PxPct>) -> Self
Specifies the offset of the left edge.
Sourcepub fn right_offset(self, right_offset: impl Into<PxPct>) -> Self
pub fn right_offset(self, right_offset: impl Into<PxPct>) -> Self
Specifies the offset of the right edge.
Sourcepub fn top_offset(self, top_offset: impl Into<PxPct>) -> Self
pub fn top_offset(self, top_offset: impl Into<PxPct>) -> Self
Specifies the offset of the top edge.
Sourcepub fn bottom_offset(self, bottom_offset: impl Into<PxPct>) -> Self
pub fn bottom_offset(self, bottom_offset: impl Into<PxPct>) -> Self
Specifies the offset of the bottom edge.