Dimension

Struct Dimension 

pub struct Dimension(/* private fields */);
A unit of linear measurement

This is commonly combined with [Rect], Point and Size<T>.

Implementations



impl Dimension

pub const fn length(val: f32) -> Dimension

An absolute length in some abstract units. Users of Taffy may define what they correspond to in their application (pixels, logical pixels, mm, etc) as they see fit.

pub const fn percent(val: f32) -> Dimension

A percentage length relative to the size of the containing block.

NOTE: percentages are represented as a f32 value in the range [0.0, 1.0] NOT the range [0.0, 100.0]

pub const fn auto() -> Dimension

The dimension should be automatically computed according to algorithm-specific rules regarding the default size of boxes.

pub fn calc(ptr: *const ()) -> Dimension

A calc() value. The value passed here is treated as an opaque handle to the actual calc representation and may be a pointer, index, etc.

The low 3 bits are used as a tag value and will be returned as 0.

pub unsafe fn from_raw(val: CompactLength) -> Dimension

Create a LengthPercentageAuto from a raw CompactLength.

Safety

CompactLength must represent a valid variant for LengthPercentageAuto

pub fn into_raw(self) -> CompactLength

Get the underlying CompactLength representation of the value

pub fn into_option(self) -> Option<f32>

Get Length value if value is Length variant

pub fn is_auto(self) -> bool

Returns true if value is Auto

pub fn tag(self) -> usize

Get the raw CompactLength tag

pub fn value(self) -> f32

Get the raw CompactLength value for non-calc variants that have a numeric parameter