InteractionState

Struct InteractionState 

pub struct InteractionState {
Show 13 fields pub is_hovered: bool, pub is_selected: bool, pub is_disabled: bool, pub is_focused: bool, pub is_focus_within: bool, pub is_hidden: bool, pub is_active: bool, pub is_dark_mode: bool, pub is_file_hover: bool, pub using_keyboard_navigation: bool, pub child_index: Option<usize>, pub sibling_count: usize, pub window_width: f64,
}
The interaction state of a view, used to determine which style selectors apply.

This struct captures the current state of user interaction with a view, such as whether it’s hovered, focused, being clicked, etc. This state is used during style computation to apply conditional styles like :hover, :active, :focus, etc.

Fields

is_hovered: bool

Whether the pointer is currently over this element.

is_selected: bool

Whether this element is in a selected state.

is_disabled: bool

Whether this element is disabled.

is_focused: bool

Whether this element has keyboard focus.

is_focus_within: bool

Whether this element or a descendant currently has keyboard focus.

is_hidden: bool

Whether the element has been hidden

is_active: bool

Whether an element is currently in the “active” state active: pointer down and not up with the pointer in the element either by 1: remaining in or 2: returning into the element or keyboard trigger is down.

is_dark_mode: bool

Whether dark mode is enabled.

is_file_hover: bool

Whether a file is being dragged over this element.

using_keyboard_navigation: bool

Whether keyboard navigation is active.

child_index: Option<usize>

1-based child index within parent, if this view has a parent.

sibling_count: usize

Number of siblings under this view’s parent.

window_width: f64

Current window width in px for responsive selector matching.