pub struct ObjectFitProp;Expand description
Controls how replaced content (like images) should be resized to fit its container.
This property specifies how an image or other replaced element should be resized
to fit within its container while potentially preserving its aspect ratio.
Corresponds to the CSS object-fit property.